@@ -37,7 +37,7 @@ interscal <- function(sym.data) {
     VecP <- ds$vector
     n <- 2 * sym.data$N
     m <- sym.data$M
-    if (n < m)
+    if (n < m) 
         nn <- min(n, m) else nn <- m
     prin.com <- matrix(0, n, nn)
     for (i in 1:n) {
@@ -57,9 +57,9 @@ interscal <- function(sym.data) {
             max <- prin.com[ii, j]
             min <- prin.com[ii, j]
             for (k in ii:(2 * i)) {
-                if (prin.com[k, j] > max)
+                if (prin.com[k, j] > max) 
                   max <- prin.com[k, j]
-                if (prin.com[k, j] < min)
+                if (prin.com[k, j] < min) 
                   min <- prin.com[k, j]
             }
             Min[i, j] <- min
@@ -69,10 +69,8 @@ interscal <- function(sym.data) {
     for (i in 1:NObjSimb) {
         posd <- 1
         for (j in 1:nn) {
-            sym.comp$meta[i, sym.comp$sym.var.starts[j]] <- Min[i,
-                j]
-            sym.comp$meta[i, sym.comp$sym.var.starts[j] + 1] <- Max[i,
-                j]
+            sym.comp$meta[i, sym.comp$sym.var.starts[j]] <- Min[i, j]
+            sym.comp$meta[i, sym.comp$sym.var.starts[j] + 1] <- Max[i, j]
             sym.comp$data[i, posd] <- Min[i, j]
             sym.comp$data[i, posd + 1] <- Max[i, j]
             posd <- posd + 2
