@@ -8,7 +8,6 @@ sym.data.table.to.sym.var <- function(sym.var) {
     new.sym.var$obj.names <- sym.var$sym.obj.names
     pos <- sym.var$sym.var.starts
     adv <- sym.var$sym.var.length
-    new.sym.var$var.data.vector <- sym.var$meta[, (pos:(pos + adv - 
-        1))]
+    new.sym.var$var.data.vector <- sym.var$meta[, (pos:(pos + adv - 1))]
     return(new.sym.var)
 }
